Coverage for pages.context_processors: 67%

# Coverage for pages.context_processors : 67%

## 6 statements 4 run 0 excluded 2 missing

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | """Context processors for Page CMS.""" from pages import settings def media(request): """Adds media-related variables to the `context`.""" return { 'PAGES_MEDIA_URL': settings.PAGES_MEDIA_URL, 'PAGE_USE_SITE_ID': settings.PAGE_USE_SITE_ID, 'PAGE_HIDE_SITES': settings.PAGE_HIDE_SITES, } def pages_navigation(request): """Adds essential pages variables to the `context`.""" pages = Page.objects.navigation().order_by("tree_id") return { 'pages_navigation': pages, 'current_page':None }